camelot.camelot.view.mainwindow

Package camelot :: Package camelot :: Package view :: Module mainwindow |
[hide private]
[frames] | no frames]

# Module mainwindow

source code

Main window GUI

Classes | [hide private]
| MainWindow

Variables | [hide private]
| logger = `logging.getLogger('mainwindow')`
| QT_MAJOR_VERSION = `float('.'.join(str(QtCore.QT_VERSION_STR).s`...``
| _ = `lambda x:`

Variables Details | [hide private]

  ### QT_MAJOR_VERSION Value:
      float('.'.join(str(QtCore.QT_VERSION_STR).split('.') [0: 2]))